import React, { Component } from "react";
import { connect } from "react-redux";

import Form from "../components/redux-form/form";
import HOCcomponent from "../components/HOC/resize";
import Button from "../components/button/button";

const list = [
	{
		id: "1",
		editable: true,
		firstName: "Tony",
		lastName: "Montana",
		age: 50,
		hobby: ["drugs", "guns"]
	}
];

class Main extends Component {
	state = { list, initialValues: {} };

	addItemEvent = item => this.setState(prevState => ({ ...prevState, list: prevState.list.concat(item) }));

	editItem = item =>
		this.setState(prevState => ({
			...prevState,
			list: prevState.list.map(el => (el.id === item.id ? item : el))
		}));

	setInitialValues = id =>
		this.setState(prevState => ({
			...prevState,
			initialValues: prevState.list.find(el => el.id === id)
		}));

	resetInitValue = () => this.setState({ initialValues: {} });

	render() {
		console.log("initialValues", this.state.initialValues);
		return (
			<>
				<div style={{ border: "1px solid #eee", textAlign: "center", padding: 10 }}>
					Now your screen size:
					<p>W = {this.props.w}</p>
					<p>H = {this.props.h}</p>
				</div>
				<div className="box">
					<div className="list">
						{this.state.list.map(el => (
							<div className="list__item" key={el.id}>
								<Button text="&nbsp;" className="list__rm-btn" onClick={() => {}} />
								{el.editable && (
									<Button
										text="&nbsp;"
										className="list__edit-btn"
										onClick={this.setInitialValues.bind(null, el.id)}
									/>
								)}
								<h4 className="list__item-title">{el.firstName}</h4>
								<p className="list__item-age">Age: {el.age}</p>
								<ul className="list__item-ul">
									{el.hobby.map(elem => (
										<li className="list__item-li" key={elem}>
											{elem}
										</li>
									))}
								</ul>
							</div>
						))}
					</div>
					<Form
						addItemEvent={this.addItemEvent}
						initialValues={this.state.initialValues}
						editItem={this.editItem}
						resetInitValue={this.resetInitValue}
					/>
				</div>
			</>
		);
	}
}

export default connect()(HOCcomponent(Main));
