import React, { useEffect, lazy, Suspense } from "react";
import { Switch, withRouter } from "react-router-dom";

import Header from "./components/header";

import { PrivateRoute } from "./private-router";
import { checkJWT } from "./utils/checkJWT";

const PAGENOTFOUND = () => <div>PAGE 404 NOT FOUND</div>;

const route = [
	{
		id: 1,
		exact: true,
		path: "/",
		protected: false,
		// hasAccess: [],
		component: lazy(() => import("./containers/main"))
	},
	{
		id: 5,
		exact: true,
		path: "/auth",
		protected: false,
		component: lazy(() => import("./containers/auth"))
	},
	{
		id: 2,
		exact: true,
		path: "/count",
		protected: true,
		component: lazy(() => import("./containers/count"))
	},
	{
		id: 3,
		exact: true,
		path: "/redux-todo",
		protected: true,
		component: lazy(() => import("./containers/reduxTodo"))
	},
	{
		id: 6,
		exact: true,
		path: "/form",
		protected: false,
		component: lazy(() => import("./containers/remote-todo"))
	},
	{
		id: 4,
		component: PAGENOTFOUND
	}
];

export const App = withRouter(({ history }) => {
	useEffect(() => {
		const token = localStorage.getItem("token");
		if (token) {
			const exp = checkJWT(token);
			if (!exp) {
				history.push("/auth");
				localStorage.removeItem("token");
			}
		}
	}, [history]);

	return (
		<div className="container">
			<Suspense fallback={<div>Loading...</div>}>
				<Header />
				<Switch>
					{route.map(el => (
						<PrivateRoute
							protectedRoute={el.protected}
							key={el.id}
							exact={el.exact}
							path={el.path}
							component={el.component}
						/>
					))}
				</Switch>
			</Suspense>
		</div>
	);
});
